Type Alias U5
Source pub type U5 = UInt<UInt<UInt<UTerm, B1>, B0>, B1>;
pub struct U5 { }
The mask used to discard bits before this bit (i.e. if this bit is 5, ANDing this mask with
a u8 will ensure bits 7 and 6 are 0.
The mask used to extract the single bit from a byte
The mask used to discard bits after this bit (i.e. if this bit is 5, ANDing this mask with
a u8 will ensure bits 4 to 0 are 0